[][src]Struct devd_rs::Context

pub struct Context { /* fields omitted */ }

Methods

impl Context[src]

pub fn new() -> Result<Context>[src]

pub fn wait_for_event_raw(&mut self, timeout_ms: usize) -> Result<String>[src]

Waits for an event using poll(), reads it but does not parse

pub fn wait_for_event<'a>(&mut self, timeout_ms: usize) -> Result<Event>[src]

Waits for an event using poll(), reads and parses it

pub fn fd(&self) -> RawFd[src]

Returns the devd socket file descriptor in case you want to select/poll on it together with other file descriptors

pub fn read_event(&mut self) -> Result<Event>[src]

Reads an event and parses it. Use when polling on the raw fd by yourself